<template>
  <el-dialog
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
  >
    <el-tabs type="border-card" ref="tabs">
      <el-tab-pane label="材料">
        <el-form
          :model="dataForm"
          :rules="dataRule"
          ref="dataForm"
          label-width="80px"
          class="l-mes"
          :disabled="!editable"
        >
          <el-row>
            <el-col :span="12">
              <el-form-item label="报废单号" prop="scrapNo">
                <el-input
                  v-model="dataForm.scrapNo"
                  placeholder="报废单号"
                  disabled
                ></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="报废类型" prop="scrapType">
                <el-select
                  v-model="dataForm.scrapType"
                  placeholder="仓库类型"
                  filterable
                  style="width: 100%"
                >
                  <el-option
                    v-for="item in scrapTypeOption"
                    :key="item.id"
                    :label="item.label"
                    :value="item.value"
                  />
                </el-select>
              </el-form-item>
            </el-col>
          </el-row>
          <el-row>
            <el-col :span="12">
              <el-form-item label="报废描述" prop="scrapDesc">
                <el-input
                  v-model="dataForm.scrapDesc"
                  placeholder="报废描述"
                ></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="工厂" prop="factoryId">
                <el-select
                  v-model="dataForm.factoryId"
                  filterable
                  placeholder=""
                  style="width:100%"
                >
                  <el-option
                    v-for="item in factoryOptions"
                    :key="item.id"
                    :label="item.factoryName"
                    :value="item.id"
                  >
                  </el-option>
                </el-select>
              </el-form-item>
            </el-col>
          </el-row>
          <el-row>
            <el-col :span="12">
              <el-form-item label="状态" prop="scrapStatus">
                <el-input
                  v-model="dataForm.scrapStatus"
                  placeholder="状态"
                  disabled
                ></el-input>
              </el-form-item>
            </el-col>
          </el-row>
        </el-form>
      </el-tab-pane>
      <el-tab-pane label="材料申请明细">
        <scrap-detail
          :scrapMainId="dataForm.id"
          :scrapNo="dataForm.scrapNo"
          :visible="visible"
          ref="scrapDetail"
        >
        </scrap-detail>
      </el-tab-pane>
    </el-tabs>
    <span slot="footer" class="dialog-footer">
      <el-button
        type="primary"
        :loading="saveLoading"
        @click="dataFormSubmit(false)"
        >保存</el-button
      >
      <el-button
        type="primary"
        :loading="saveAndReturnLoading"
        @click="dataFormSubmit(true)"
        >保存并返回</el-button
      >
    </span>
  </el-dialog>
</template>

<script>
import { addObj, getObj, putObj } from '@/api/warehouse/scrapmain'
import ScrapDetail from './scrapdetail'
import { remote } from '../../../api/admin/dict'
import { loadFactoryList } from '../../../api/basic/factory'

export default {
  data() {
    return {
      factoryOptions: [],
      status: false,
      scrapTypeOption: [],
      isDisable: false,
      visible: false,
      dataForm: {
        id: 0,
        scrapNo: '',
        scrapType: '',
        scrapDesc: '',
        factoryId: '',
        scrapStatus: ''
      },
      dataRule: {
        scrapType: [
          { required: true, message: '报废类型不能为空', trigger: 'blur' }
        ],
        scrapStatus: [
          { required: true, message: '状态不能为空', trigger: 'blur' }
        ]
      },
      saveLoading: false,
      saveAndReturnLoading: false
    }
  },
  computed: {
    editable: function() {
      if (!this.dataForm.id) {
        return true
      }
      if (this.dataForm.id && this.dataForm.scrapStatus == '未下发') {
        return true
      }
      return false
    }
  },
  created() {
    this.getWarehouseScrapType()
    this.initFactorySelect()
  },
  components: { ScrapDetail },
  methods: {
    getWarehouseScrapType() {
      remote('scrap_main_type').then((response) => {
        if (response.data.code === 0) {
          this.scrapTypeOption = response.data.data
        }
      })
    },
    // 获取工厂的数据
    initFactorySelect() {
      loadFactoryList().then((res) => {
        this.factoryOptions = res.data
      })
    },
    init(id) {
      this.dataForm.id = id || 0
      this.visible = true
      this.dataForm.scrapStatus = '未下发'
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        if (this.dataForm.id) {
          getObj(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
          })
        } else {
          this.$refs.tabs.currentName = '0'
        }
      })
    },
    // 表单提交
    dataFormSubmit(status) {
      if (status) {
        this.saveAndReturnLoading = true
      } else {
        this.saveLoading = true
      }
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          if (this.dataForm.id) {
            putObj(this.dataForm).then((data) => {
              this.$message.success('修改成功')
              this.$emit('refreshDataList')
              if (status) {
                this.visible = false
                this.saveAndReturnLoading = false
              } else {
                this.saveLoading = false
              }
            })
          } else {
            addObj(this.dataForm).then((response) => {
              this.$message.success('添加成功')
              this.$emit('refreshDataList')
              this.dataForm = response.data.data
              if (status) {
                this.visible = false
                this.saveAndReturnLoading = false
              } else {
                this.saveLoading = false
              }
            })
          }
        } else {
          this.saveAndReturnLoading = false
          this.saveLoading = false
        }
      })
    }
  }
}
</script>
